==> rx-css-loader-0.1.3.tgz: package/rx-stylesheet-css/lib/parseCss.js <==
var Handle = require('./Handle');

var format = require('./properties/all'),
	margingAndPadding = require('./properties/marginAndPadding'),
	boxShadow = require('./properties/boxShadow'),
	border = require('./properties/border'),
	flex = require('./properties/flex'),
	transform = require('./properties/transform'),
	lineHeight = require('./properties/lineHeight'),
    zIndex = require('./properties/zIndex');
	final = require('./saveAll');

module.exports = function (css,sourcePath) {
	var handle = new Handle(css,sourcePath);

	handle.use(['margin', 'padding'], margingAndPadding);
	handle.use([
		'border',
		'border-top',
		'borderTop',
		'border-bottom',
		'borderBottom',
		'border-left',
		'borderLeft',
		'border-right',
		'borderRight',
		'border-width',
		'borderWidth',
		'border-top-width',
		'borderTopWidth',
		'border-right-width',
		'borderRightWidth',
		'border-bottom-width',
		'borderBottomWidth',
		'border-left-width',
		'borderLeftWidth',
		'border-style',
		'borderStyle',
		'border-top-style',
		'borderTopStyle',
		'border-right-style',
		'borderRightStyle',
		'border-bottom-style',
		'borderBottomStyle',
		'border-left-style',
		'borderLeftStyle',
		'border-color',
		'borderColor'
	], border);
	handle.use(['box-shadow', 'boxShadow'], boxShadow);
	handle.use(['flex'], flex);
	handle.use(['transform'], transform);
	handle.use(['line-height'], lineHeight);
    // handle.use(['z-index'],zIndex);
	handle.use(format,null,sourcePath);

	handle.final(final);

	return handle.do();
};

==> rx-css-loader-0.1.13.tgz: package/rx-stylesheet-css/lib/parseCss.js <==
var Handle = require('./Handle');

var format = require('./properties/all'),
	margingAndPadding = require('./properties/marginAndPadding'),
	boxShadow = require('./properties/boxShadow'),
	border = require('./properties/border'),
	flex = require('./properties/flex'),
	transform = require('./properties/transform'),
	// lineHeight = require('./properties/lineHeight'),
    zIndex = require('./properties/zIndex');
	final = require('./saveAll');

module.exports = function (css,sourcePath) {
	var handle = new Handle(css,sourcePath);

	handle.use(['margin', 'padding'], margingAndPadding);
	handle.use([
		'border',
		'border-top',
		'borderTop',
		'border-bottom',
		'borderBottom',
		'border-left',
		'borderLeft',
		'border-right',
		'borderRight',
		'border-width',
		'borderWidth',
		'border-top-width',
		'borderTopWidth',
		'border-right-width',
		'borderRightWidth',
		'border-bottom-width',
		'borderBottomWidth',
		'border-left-width',
		'borderLeftWidth',
		'border-style',
		'borderStyle',
		'border-top-style',
		'borderTopStyle',
		'border-right-style',
		'borderRightStyle',
		'border-bottom-style',
		'borderBottomStyle',
		'border-left-style',
		'borderLeftStyle',
		'border-color',
		'borderColor'
	], border);
	handle.use(['box-shadow', 'boxShadow'], boxShadow);
	handle.use(['flex'], flex);
	handle.use(['transform'], transform);
	// handle.use(['line-height'], lineHeight);
    // handle.use(['z-index'],zIndex);
	handle.use(format,null,sourcePath);

	handle.final(final);

	return handle.do();
};
